@@ -4,7 +4,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 3 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,9 +12,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
@@ -57,21 +56,21 @@ image_new (BablFormat     *format,
   babl->image.model      = model;
   babl->image.components = components;
 
-  memcpy (babl->image.component, component, components * sizeof(void*));
-  memcpy (babl->image.type,      type,      components * sizeof(void*));
-  memcpy (babl->image.data,      data,      components * sizeof(void*));
-  memcpy (babl->image.pitch,     pitch,     components * sizeof(int));
-  memcpy (babl->image.stride,    stride,    components * sizeof(int));
+  memcpy (babl->image.component, component, components * sizeof (void *));
+  memcpy (babl->image.type, type, components * sizeof (void *));
+  memcpy (babl->image.data, data, components * sizeof (void *));
+  memcpy (babl->image.pitch, pitch, components * sizeof (int));
+  memcpy (babl->image.stride, stride, components * sizeof (int));
 
   return babl;
 }
 
 Babl *
-babl_image_from_linear (char  *buffer,
-                        Babl  *format)
+babl_image_from_linear (char *buffer,
+                        Babl *format)
 {
   Babl          *babl;
-  BablModel     *model = NULL;
+  BablModel     *model      = NULL;
   int            components = 0;
   int            i;
   BablComponent *component [BABL_MAX_COMPONENTS];
@@ -81,62 +80,78 @@ babl_image_from_linear (char  *buffer,
   int            pitch     [BABL_MAX_COMPONENTS];
   int            stride    [BABL_MAX_COMPONENTS];
 
-  int            offset=0;
-  int            calc_pitch=0;
+  int            offset     = 0;
+  int            calc_pitch = 0;
 
   babl_assert (format);
   babl_assert (format->class_type == BABL_FORMAT ||
                format->class_type == BABL_MODEL);
- 
+
   switch (format->class_type)
     {
       case BABL_FORMAT:
-        model = (BablModel*) format->format.model;
         components = format->format.components;
+        if (format->format.image_template != NULL) /* single item cache for speeding
+                                                      up subsequent use of linear buffers
+                                                      for subsequent accesses
+                                                    */
+          { 
+            babl = format->format.image_template;
+            format->format.image_template = NULL;
+            for (i = 0; i < components; i++)
+              {
+                babl->image.data[i] = buffer + offset;
+                offset   += (format->format.type[i]->bits / 8);
+              }
+            return babl;
+          }
+        model      = (BablModel *) format->format.model;
 
-        memcpy(component, format->format.component, sizeof (Babl*) * components);
-        memcpy(sampling,  format->format.sampling,  sizeof (Babl*) * components);
-        memcpy(type    ,  format->format.type,      sizeof (Babl*) * components);
+        memcpy (component, format->format.component, sizeof (Babl *) * components);
+        memcpy (sampling, format->format.sampling, sizeof (Babl *) * components);
+        memcpy (type, format->format.type, sizeof (Babl *) * components);
 
-        for (i=0; i < components; i++)
+        for (i = 0; i < components; i++)
           {
             calc_pitch += (type[i]->bits / 8);
           }
-        for (i=0; i < components; i++)
+        for (i = 0; i < components; i++)
           {
-            pitch[i]   = calc_pitch;
-            stride[i]  = 0;
-            data[i]    = buffer + offset;
-            offset       += (type[i]->bits / 8);
+            pitch[i]  = calc_pitch;
+            stride[i] = 0;
+            data[i]   = buffer + offset;
+            offset   += (type[i]->bits / 8);
           }
         break;
+
       case BABL_MODEL:
-        model = (BablModel*) format;
+        model      = (BablModel *) format;
         components = format->format.components;
-        for (i=0; i < components; i++)
+        for (i = 0; i < components; i++)
           {
             calc_pitch += (64 / 8);   /*< known to be double when we create from model */
           }
-        memcpy(component, model->component, sizeof (Babl*) * components);
-        for (i=0; i < components; i++)
+        memcpy (component, model->component, sizeof (Babl *) * components);
+        for (i = 0; i < components; i++)
           {
-            sampling[i]  = (BablSampling*)babl_sampling (1,1);
-            type[i]      = (BablType*)babl_type_id (BABL_DOUBLE);
-            pitch[i]     = calc_pitch;
-            stride[i]    = 0;
-            data[i]      = buffer + offset;
-            offset         += (type[i]->bits / 8);
+            sampling[i] = (BablSampling *) babl_sampling (1, 1);
+            type[i]     = (BablType *) babl_type_id (BABL_DOUBLE);
+            pitch[i]    = calc_pitch;
+            stride[i]   = 0;
+            data[i]     = buffer + offset;
+            offset     += (type[i]->bits / 8);
           }
         break;
+
       default:
         babl_log ("Eeeek!");
         break;
     }
 
   babl = image_new (
-         (BablFormat*)format,
-        model, components,
-        component, sampling, type, data, pitch, stride);
+    ((void*)format!=(void*)model)?(BablFormat*)format:NULL,
+    model, components,
+    component, sampling, type, data, pitch, stride);
   return babl;
 }
 
@@ -146,9 +161,9 @@ babl_image (void *first,
 {
   va_list        varg;
   Babl          *babl;
-  int            components= 0;
-  BablFormat    *format    = NULL;
-  BablModel     *model     = NULL;
+  int            components = 0;
+  BablFormat    *format     = NULL;
+  BablModel     *model      = NULL;
   BablComponent *component [BABL_MAX_COMPONENTS];
   BablSampling  *sampling  [BABL_MAX_COMPONENTS];
   BablType      *type      [BABL_MAX_COMPONENTS];
@@ -156,7 +171,7 @@ babl_image (void *first,
   int            pitch     [BABL_MAX_COMPONENTS];
   int            stride    [BABL_MAX_COMPONENTS];
 
-  const char      *arg = first;
+  const char    *arg = first;
 
   va_start (varg, first);
 
@@ -168,41 +183,41 @@ babl_image (void *first,
 
       if (BABL_IS_BABL (arg))
         {
-          Babl *babl = (Babl*)arg;
+          Babl *babl = (Babl *) arg;
 
           if (babl->class_type == BABL_COMPONENT)
             {
-              new_component = (BablComponent *)babl;
+              new_component = (BablComponent *) babl;
             }
           else
             {
-                babl_log ("%s unexpected", babl_class_name (babl->class_type));
-                return NULL;
+              babl_log ("%s unexpected", babl_class_name (babl->class_type));
+              return NULL;
             }
         }
       else
         {
-          new_component = (BablComponent*) babl_component (arg);
+          new_component = (BablComponent *) babl_component (arg);
         }
 
       /* FIXME: add error checking */
       component [components] = new_component;
       sampling  [components] = NULL;
       type      [components] = NULL;
-      data      [components] = va_arg (varg, void*);
+      data      [components] = va_arg (varg, void *);
       pitch     [components] = va_arg (varg, int);
       stride    [components] = va_arg (varg, int);
       components++;
-                
-      if (components>=BABL_MAX_COMPONENTS)
+
+      if (components >= BABL_MAX_COMPONENTS)
         {
           babl_log ("maximum number of components (%i) exceeded", BABL_MAX_COMPONENTS);
         }
 
       arg = va_arg (varg, char *);
     }
-    
-  va_end   (varg);
+
+  va_end (varg);
 
 
   babl = image_new (format, model, components, component, sampling, type, data, pitch, stride);
